==> haskell-language-c-0.7.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.7.1
id: language-c-0.7.1-IGeGUhRFB0oKu0O8FPLNrc
key: language-c-0.7.1-IGeGUhRFB0oKu0O8FPLNrc
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://visq.github.io/language-c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.
category: Language
author: AUTHORS
exposed: True
indefinite: False
exposed-modules:
    Language.C Language.C.Analysis Language.C.Analysis.AstAnalysis
    Language.C.Analysis.Builtins Language.C.Analysis.ConstEval
    Language.C.Analysis.Debug Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.DefTable Language.C.Analysis.Export
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.SemError
    Language.C.Analysis.SemRep Language.C.Analysis.TravMonad
    Language.C.Analysis.TypeCheck Language.C.Analysis.TypeConversions
    Language.C.Analysis.TypeUtils Language.C.Data Language.C.Data.Error
    Language.C.Data.Ident Language.C.Data.InputStream
    Language.C.Data.Name Language.C.Data.Node Language.C.Data.Position
    Language.C.Parser Language.C.Pretty Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.System.GCC
    Language.C.System.Preprocess
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
abi: 33718e4b9a4c93f2190fe40be2236806
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/language-c-0.7.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/language-c-0.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/language-c-0.7.1
hs-libraries: HSlanguage-c-0.7.1-IGeGUhRFB0oKu0O8FPLNrc
depends:
    filepath-1.4.1.2 base-4.10.1.0 process-1.6.1.0 directory-1.3.0.2
    array-0.5.2.0 containers-0.5.10.2 pretty-1.1.3.3
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 bytestring-0.10.8.2
abi-depends: filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             pretty-1.1.3.3=da5c0455980712cd8d78cc4bdcee49dd
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=06df45b1c27c5cef935930b2f87d2689
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-c-0.7.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.7.2
id: language-c-0.7.2-80gnm5tZIr6FsKNoqtp2DN
key: language-c-0.7.2-80gnm5tZIr6FsKNoqtp2DN
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://visq.github.io/language-c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.
category: Language
author: AUTHORS
exposed: True
indefinite: False
exposed-modules:
    Language.C Language.C.Analysis Language.C.Analysis.AstAnalysis
    Language.C.Analysis.Builtins Language.C.Analysis.ConstEval
    Language.C.Analysis.Debug Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.DefTable Language.C.Analysis.Export
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.SemError
    Language.C.Analysis.SemRep Language.C.Analysis.TravMonad
    Language.C.Analysis.TypeCheck Language.C.Analysis.TypeConversions
    Language.C.Analysis.TypeUtils Language.C.Data Language.C.Data.Error
    Language.C.Data.Ident Language.C.Data.InputStream
    Language.C.Data.Name Language.C.Data.Node Language.C.Data.Position
    Language.C.Parser Language.C.Pretty Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.System.GCC
    Language.C.System.Preprocess
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
abi: 1f6400a6ede04b36c2c5b53910b68632
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/language-c-0.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/language-c-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/language-c-0.7.2
hs-libraries: HSlanguage-c-0.7.2-80gnm5tZIr6FsKNoqtp2DN
depends:
    filepath-1.4.1.2 base-4.10.1.0 process-1.6.1.0 directory-1.3.0.2
    array-0.5.2.0 containers-0.5.10.2 pretty-1.1.3.3
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 bytestring-0.10.8.2
abi-depends: filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             pretty-1.1.3.3=da5c0455980712cd8d78cc4bdcee49dd
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=06df45b1c27c5cef935930b2f87d2689
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
